==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/BreakOut/ts/BreakOut_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>BreakOut</name>
    <message>
        <source>Choose line, arc, circle or ellipse to auto trim</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz linię, łuk, okrąg lub elipsę do wykończenia auto</translation>
    </message>
    <message>
        <location filename="../BreakOut.js" line="+58"/>
        <source>Choose line, arc, circle, ellipse, spline or polyline segment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose line, arc, circle or ellipse segment</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wybierz segment linii, łuku, okręgu lub elipsy</translation>
    </message>
    <message>
        <location filename="../BreakOut.ui" line="+17"/>
        <source>Remove Segment</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zaznacz, aby usunąć odcinki, odznacz aby je zachować
Usuń odcinek</translatorcomment>
        <translation type="unfinished">Usuń odcinek</translation>
    </message>
    <message>
        <location filename="../BreakOutInit.js" line="+2"/>
        <source>&amp;Break out Segment</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Podziel &amp;2</translatorcomment>
        <translation type="unfinished">Podziel &amp;2</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/BreakOut/ts/BreakOut_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>BreakOut</name>
    <message>
        <source>Choose line, arc, circle or ellipse to auto trim</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz linię, łuk, okrąg lub elipsę do wykończenia auto</translation>
    </message>
    <message>
        <location filename="../BreakOut.js" line="+58"/>
        <source>Choose line, arc, circle, ellipse, spline or polyline segment</source>
        <translation>Proszę wskazać segment linii, łuku, elipsy, splajnu lub linii łamanej</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose line, arc, circle or ellipse segment</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać segment linii, łuku, okręgu lub elipsy</translation>
    </message>
    <message>
        <location filename="../BreakOut.ui" line="+17"/>
        <source>Remove Segment</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zaznacz, aby usunąć odcinki, odznacz aby je zachować
Usuń odcinek</translatorcomment>
        <translation>Usunięcie segmentu</translation>
    </message>
    <message>
        <location filename="../BreakOutInit.js" line="+2"/>
        <source>&amp;Break out Segment</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Podziel &amp;2</translatorcomment>
        <translation>O&amp;ddziel segment</translation>
    </message>
</context>
</TS>
